from django.forms.models import ModelForm
from django import forms
from .consts import *


class AnimateOnScroll_Element_Form(ModelForm):

    aos_animation = forms.ChoiceField(choices=AOS_ANIMATIONS)

    aos_easing = forms.ChoiceField(choices=AOS_EASING, required=False)

    aos_anchor_placement = forms.ChoiceField(choices=AOS_ANCHOR_PLACEMENT, required=False)


# -*- coding: utf-8 -*-
"""
Enables the user to add style plugin that displays a html tag with
the provided settings from the style plugin.
"""
from __future__ import unicode_literals

from cms.models import CMSPlugin
from django.db import models
from django.utils.encoding import python_2_unicode_compatible
from django.utils.translation import ugettext_lazy as _
from djangocms_attributes_field.fields import AttributesField
from django.utils.text import slugify
from django.db.models.deletion import SET_NULL
import json


@python_2_unicode_compatible
class AnimateOnScroll_Anchor(CMSPlugin):
    id_name = models.CharField(
        verbose_name=_('ID name'),
        max_length=255,
    )
    def __str__(self):
        return self.id_name

    def clean(self):
        valid_id_name = slugify(self.id_name)
        self.id_name = valid_id_name


@python_2_unicode_compatible
class AnimateOnScroll_Element(CMSPlugin):

    # AOS Standard
    # --------------------------------
    aos_animation = models.CharField(verbose_name=_('AOS Animation'),
                                        max_length=255,
                                        help_text=_('Script will trigger "animation_name" animation on this element, if you scroll to it.'))

    aos_easing = models.CharField(verbose_name=_('Anchor Easing'),
                                    blank=True,
                                    max_length=255,
                                    help_text=_('Choose timing function to ease elements in different ways'))

    # AOS Anchors
    # --------------------------------
    aos_anchor_placement = models.CharField(verbose_name=_('Anchor Placement'),
                                            blank=True,
                                            max_length=255,
                                            help_text=_(
                                                'Anchor placement - which one position of element on the screen should trigger animation'))

    aos_anchor = models.ForeignKey(AnimateOnScroll_Anchor,
                                    verbose_name=_("Animate On Scroll Anchor"),
                                    related_name="aos_anchor",
                                    blank=True,
                                    null=True,
                                    help_text=_('Anchor element, whose offset will be counted to trigger animation instead of actual elements offset'),
                                    on_delete=SET_NULL)

    # AOS Advanced
    # --------------------------------
    aos_offset = models.IntegerField(verbose_name=_('Offset'),
                                     default=120,
                                     help_text=_('Change offset to trigger animations sooner or later (px)'))
    aos_duration = models.IntegerField(verbose_name=_('Duration'),
                                       default=400,
                                       help_text=_('*Duration of animation (ms)'))
    aos_delay = models.IntegerField(verbose_name=_('Delay'),
                                    default=0,
                                    help_text=_('Delay animation (ms)'))
    aos_once = models.BooleanField(verbose_name=_('Once'),
                                   default=False,
                                   help_text=_('Choose wheter animation should fire once, or every time you scroll up/down to element'))


    # Default id/classes/attributes
    # --------------------------------
    id_name = models.CharField(
        verbose_name=_('ID name'),
        blank=True,
        max_length=255,
    )
    additional_classes = models.CharField(
        verbose_name=_('Additional classes'),
        blank=True,
        max_length=255,
        help_text=_('Additional comma separated list of classes '
            'to be added to the element e.g. "row, column-12, clearfix".'),
    )
    attributes = AttributesField(
        verbose_name=_('Attributes'),
        blank=True,
        excluded_keys=['class', 'id', 'style'],
    )

    def get_aos_once(self):
        return json.dumps(self.aos_once)

    def get_additional_classes(self):
        return ' '.join(item.strip() for item in self.additional_classes.split(',') if item.strip())


    def __str__(self):
        return ('%s - ' % self.aos_animation) + self.aos_anchor_placement + self.id_name or str(self.pk)





AOS_ANIMATIONS = ['fade',
                    'fade-up',
                    'fade-down',
                    'fade-left',
                    'fade-right',
                    'fade-up-right',
                    'fade-up-left',
                    'fade-down-right',
                    'fade-down-left',
                    'flip-up',
                    'flip-down',
                    'flip-left',
                    'flip-right',
                    'slide-up',
                    'slide-down',
                    'slide-left',
                    'slide-right',
                    'zoom-in',
                    'zoom-in-up',
                    'zoom-in-down',
                    'zoom-in-left',
                    'zoom-in-right',
                    'zoom-out',
                    'zoom-out-up',
                    'zoom-out-down',
                    'zoom-out-left',
                    'zoom-out-right',
                    ]


AOS_ANCHOR_PLACEMENT = [None,
                        'top-bottom',
                        'top-center',
                        'top-top',
                        'center-bottom',
                        'center-center',
                        'center-top',
                        'bottom-bottom',
                        'bottom-center',
                        'bottom-top',
                        ]



AOS_EASING = [None,
              'linear',
                'ease',
                'ease-in',
                'ease-out',
                'ease-in-out',
                'ease-in-back',
                'ease-out-back',
                'ease-in-out-back',
                'ease-in-sine',
                'ease-out-sine',
                'ease-in-out-sine',
                'ease-in-quad',
                'ease-out-quad',
                'ease-in-out-quad',
                'ease-in-cubic',
                'ease-out-cubic',
                'ease-in-out-cubic',
                'ease-in-quart',
                'ease-out-quart',
                'ease-in-out-quart',
                ]

AOS_ANIMATIONS = ((a, a) for a in AOS_ANIMATIONS)
AOS_ANCHOR_PLACEMENT = ((a, a) for a in AOS_ANCHOR_PLACEMENT)
AOS_EASING = ((a, a) for a in AOS_EASING)


# /usr/bin/env python
import codecs
import os
from setuptools import setup, find_packages

read = lambda filepath: codecs.open(filepath, 'r', 'utf-8').read()

setup(
    name='djangocms-animate-on-scroll',
    version='1.0.0',
    description='Allows you to add the animate on scroll plugin to a cms page',
    long_description=read(os.path.join(os.path.dirname(__file__), 'README.rst')),
    author='michalsnik, Michael Carder',
    license='MIT',
    url='https://github.com/mcldev/djangocms-animate-on-scroll',
    packages=find_packages(),
    zip_safe=False,
    include_package_data=True,
    install_requires=[
        'Django>=1.11',
        'django-cms>=3.5',
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Framework :: Django',
        'Framework :: Django :: 1.11',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)



# -*- coding: utf-8 -*-
from django.utils.translation import ugettext_lazy as _

from cms.plugin_pool import plugin_pool
from cms.plugin_base import CMSPluginBase

from .models import AnimateOnScroll_Element, AnimateOnScroll_Anchor
from .forms import AnimateOnScroll_Element_Form

class AnimateOnScroll_Anchor_Plugin(CMSPluginBase):
    model = AnimateOnScroll_Anchor
    name = _('AnimateOnScroll - Anchor')
    module = _('Animate On Scroll')
    render_template = 'djangocms_animate_on_scroll/aos_anchor.html'

    fieldsets = (
        (None, {
            'fields': (
                'id_name',
            )
        }),
    )


plugin_pool.register_plugin(AnimateOnScroll_Anchor_Plugin)


class AnimateOnScroll_Element_Plugin(CMSPluginBase):
    model = AnimateOnScroll_Element
    name = _('AnimateOnScroll - Element')
    module = _('Animate On Scroll')
    render_template = 'djangocms_animate_on_scroll/aos_element.html'
    allow_children = True
    form = AnimateOnScroll_Element_Form

    fieldsets = (
        (None, {
            'fields': (
                'aos_animation',
                'aos_easing',
            )
        }),
        (_('AOS Anchor settings'), {
            'fields': (
                'aos_anchor_placement',
                'aos_anchor',
            ),
        }),
        (_('AOS Advanced settings'), {
            'classes': ('collapse',),
            'fields': (
                ('aos_offset',
                 'aos_duration',
                 'aos_delay',
                 'aos_once'),
            ),
        }),
        (_('Advanced Element settings'), {
            'classes': ('collapse',),
            'fields': (
                'id_name',
                 'additional_classes',
                 'attributes',
            ),
        }),
    )


plugin_pool.register_plugin(AnimateOnScroll_Element_Plugin)



# -*- coding: utf-8 -*-
# Generated by Django 1.11.20 on 2019-05-20 04:12
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import djangocms_attributes_field.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
    ]

    operations = [
        migrations.CreateModel(
            name='AnimateOnScroll_Anchor',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='djangocms_animate_on_scroll_animateonscroll_anchor', serialize=False, to='cms.CMSPlugin')),
                ('id_name', models.CharField(max_length=255, verbose_name='ID name')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='AnimateOnScroll_Element',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='djangocms_animate_on_scroll_animateonscroll_element', serialize=False, to='cms.CMSPlugin')),
                ('aos_animation', models.CharField(help_text='Script will trigger "animation_name" animation on this element, if you scroll to it.', max_length=255, verbose_name='AOS Animation')),
                ('aos_easing', models.CharField(blank=True, help_text='Choose timing function to ease elements in different ways', max_length=255, verbose_name='Anchor Easing')),
                ('aos_anchor_placement', models.CharField(blank=True, help_text='Anchor placement - which one position of element on the screen should trigger animation', max_length=255, verbose_name='Anchor Placement')),
                ('aos_offset', models.IntegerField(default=120, help_text='Change offset to trigger animations sooner or later (px)', verbose_name='Offset')),
                ('aos_duration', models.IntegerField(default=400, help_text='*Duration of animation (ms)', verbose_name='Duration')),
                ('aos_delay', models.IntegerField(default=0, help_text='Delay animation (ms)', verbose_name='Delay')),
                ('aos_once', models.BooleanField(default=False, help_text='Choose wheter animation should fire once, or every time you scroll up/down to element', verbose_name='Once')),
                ('id_name', models.CharField(blank=True, max_length=255, verbose_name='ID name')),
                ('additional_classes', models.CharField(blank=True, help_text='Additional comma separated list of classes to be added to the element e.g. "row, column-12, clearfix".', max_length=255, verbose_name='Additional classes')),
                ('attributes', djangocms_attributes_field.fields.AttributesField(blank=True, default=dict, verbose_name='Attributes')),
                ('aos_anchor', models.ForeignKey(blank=True, help_text='Anchor element, whose offset will be counted to trigger animation instead of actual elements offset', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='aos_anchor', to='djangocms_animate_on_scroll.AnimateOnScroll_Anchor', verbose_name='Animate On Scroll Anchor')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]
